@@ -534,13 +534,19 @@ void SkkEngine::loadDictionary() {
             if (path.empty() || mode == 0) {
                 continue;
             }
+
+            std::string_view partialpath = path;
+            if (stringutils::consumePrefix(partialpath, "$FCITX_CONFIG_DIR/")) {
+                path = StandardPaths::global().userDirectory(
+                           StandardPathsType::PkgData) /
+                       partialpath;
+            } else if (stringutils::consumePrefix(partialpath,
+                                                  "$XDG_DATA_DIRS/")) {
+                path = StandardPaths::global().locate(StandardPathsType::Data,
+                                                      partialpath);
+            }
+
             if (mode == 1) {
-                std::string_view partialpath = path;
-                if (stringutils::consumePrefix(partialpath,
-                                               "$XDG_DATA_DIRS/")) {
-                    path = StandardPaths::global().locate(
-                        StandardPathsType::Data, partialpath);
-                }
                 if (stringutils::endsWith(path, ".cdb")) {
                     SkkCdbDict *dict =
                         skk_cdb_dict_new(path.data(), encoding.data(), nullptr);
@@ -557,13 +563,6 @@ void SkkEngine::loadDictionary() {
                     }
                 }
             } else {
-                std::string_view partialpath = path;
-                if (stringutils::consumePrefix(partialpath,
-                                               "$FCITX_CONFIG_DIR/")) {
-                    path = StandardPaths::global().userDirectory(
-                               StandardPathsType::PkgData) /
-                           partialpath;
-                }
                 SkkUserDict *userdict =
                     skk_user_dict_new(path.data(), encoding.data(), nullptr);
                 if (userdict) {
@@ -674,7 +673,8 @@ bool SkkState::handleCandidate(KeyEvent &keyEvent) {
         skk_candidate_list_cursor_up(skkCandidates);
         keyEvent.filterAndAccept();
     } else if (keyEvent.key().checkKeyList(*config.cursorDownKey)) {
-        skk_candidate_list_cursor_down(skkCandidates);
+        if (!skk_candidate_list_cursor_down(skkCandidates))
+            return false;
         keyEvent.filterAndAccept();
     } else if (keyEvent.key().checkKeyList(*config.prevPageKey)) {
         skk_candidate_list_page_up(skkCandidates);
